# Quick Start

This section will be available soon, but if you'd like a quick look at how 
you can get started, head over to the [Jupyter notebook demos](https://github.com/Waveform-Analytics/yooink/tree/main/notebooks) on the github 
repository!
